==> elasticsearch-0.20.6-sources.jar: org/elasticsearch/action/admin/indices/stats/IndicesStatsAction.java <==
/*
 * Licensed to ElasticSearch and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. ElasticSearch licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.indices.stats;

import org.elasticsearch.action.admin.indices.IndicesAction;
import org.elasticsearch.client.IndicesAdminClient;

/**
 */
public class IndicesStatsAction extends IndicesAction<IndicesStatsRequest, IndicesStats, IndicesStatsRequestBuilder> {

    public static final IndicesStatsAction INSTANCE = new IndicesStatsAction();
    public static final String NAME = "indices/stats";

    private IndicesStatsAction() {
        super(NAME);
    }

    @Override
    public IndicesStats newResponse() {
        return new IndicesStats();
    }

    @Override
    public IndicesStatsRequestBuilder newRequestBuilder(IndicesAdminClient client) {
        return new IndicesStatsRequestBuilder(client);
    }
}

==> elasticsearch-0.90.1-sources.jar: org/elasticsearch/action/admin/indices/stats/IndicesStatsAction.java <==
/*
 * Licensed to ElasticSearch and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. ElasticSearch licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.indices.stats;

import org.elasticsearch.action.admin.indices.IndicesAction;
import org.elasticsearch.client.IndicesAdminClient;

/**
 */
public class IndicesStatsAction extends IndicesAction<IndicesStatsRequest, IndicesStatsResponse, IndicesStatsRequestBuilder> {

    public static final IndicesStatsAction INSTANCE = new IndicesStatsAction();
    public static final String NAME = "indices/stats";

    private IndicesStatsAction() {
        super(NAME);
    }

    @Override
    public IndicesStatsResponse newResponse() {
        return new IndicesStatsResponse();
    }

    @Override
    public IndicesStatsRequestBuilder newRequestBuilder(IndicesAdminClient client) {
        return new IndicesStatsRequestBuilder(client);
    }
}
